==> insighttoolkit4_4.5.0.orig.tar.xz: InsightToolkit-4.5.0/Modules/Nonunit/Review/test/itkShapedFloodFilledImageFunctionConditionalConstIteratorTest3.cxx <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
// Test itk::ShapedFloodFilledImageFunctionConditionalConstIterator on a 3D
// image with 6 connectivity.

#include "itkBinaryThresholdImageFunction.h"
#include "itkImageLinearIteratorWithIndex.h"
#include "itkFloodFilledImageFunctionConditionalConstIterator.h"

#include "itkShapedFloodFilledImageFunctionConditionalConstIterator.h"

int itkShapedFloodFilledImageFunctionConditionalConstIteratorTest3(int, char * [] )
{
  try
    {
    const unsigned int ImageDimension = 3;
    typedef unsigned char PixelType;

    typedef itk::Image<PixelType, ImageDimension> ImageType;
    typedef ImageType::RegionType                 RegionType;
    typedef ImageType::IndexType                  IndexType;

    typedef itk::BinaryThresholdImageFunction<ImageType> FunctionType;
    typedef itk::FloodFilledImageFunctionConditionalConstIterator<
      ImageType, FunctionType> FloodFilledIteratorType;
    typedef itk::ShapedFloodFilledImageFunctionConditionalConstIterator<
      ImageType, FunctionType> ShapedFloodFilledIteratorType;

    std::vector<IndexType> seedList;

    RegionType region;
    region.SetSize(0, 128);
    region.SetSize(1, 128);
    region.SetSize(2, 128);
    region.SetIndex(0, 0);
    region.SetIndex(1, 0);
    region.SetIndex(2, 0);

    ImageType::Pointer inputImage = ImageType::New();
    inputImage->SetRegions(region);
    inputImage->Allocate();
    inputImage->FillBuffer(0);

    itk::ImageLinearIteratorWithIndex<ImageType> it( inputImage, region );

    // make sure that we create a 4-connected image!
    for( unsigned int dir = 0; dir < ImageDimension; ++dir )
      {
      it.SetDirection(dir);
      it.GoToBegin();
      while (!it.IsAtEnd())
        {
        while (!it.IsAtEndOfLine())
          {
          // add a seed
          if (seedList.empty())
            {
            seedList.push_back(it.GetIndex());
            }

          it.Set(255);
          ++it;
          }

        // and jump over every
        it.NextLine();
        if (!it.IsAtEnd())
          {
          it.NextLine();
          }
        if (!it.IsAtEnd())
          {
          it.NextLine();
          }
        }
      }

    FunctionType::Pointer function = FunctionType::New();

    function->SetInputImage ( inputImage );
    function->ThresholdAbove ( 1 ); // >= 1

    FloodFilledIteratorType floodIt(inputImage, function, seedList);
    ShapedFloodFilledIteratorType shapedFloodIt(inputImage, function, seedList);

    shapedFloodIt.SetFullyConnected(false); // 4-connected, default

    for (unsigned short i = 1; !floodIt.IsAtEnd(); ++floodIt,
                                                   ++shapedFloodIt,
                                                   ++i)
      {
      if (floodIt.GetIndex() != shapedFloodIt.GetIndex())
        {
        return EXIT_FAILURE;
        }
      }

    if (!floodIt.IsAtEnd() || !shapedFloodIt.IsAtEnd())
      {
      return EXIT_FAILURE;
      }
    }
  catch (itk::ExceptionObject& e)
    {
    e.Print(std::cerr);
    return EXIT_FAILURE;
    }
  catch (...)
    {
    return EXIT_FAILURE;
    }

  return EXIT_SUCCESS;
}

==> insighttoolkit5_5.2.1.orig.tar.xz: InsightToolkit-5.2.1/Modules/Nonunit/Review/test/itkShapedFloodFilledImageFunctionConditionalConstIteratorTest3.cxx <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
// Test itk::ShapedFloodFilledImageFunctionConditionalConstIterator on a 3D
// image with 6 connectivity.

#include "itkBinaryThresholdImageFunction.h"
#include "itkImageLinearIteratorWithIndex.h"
#include "itkFloodFilledImageFunctionConditionalConstIterator.h"

#include "itkShapedFloodFilledImageFunctionConditionalConstIterator.h"

int
itkShapedFloodFilledImageFunctionConditionalConstIteratorTest3(int, char *[])
{
  try
  {
    constexpr unsigned int ImageDimension = 3;
    using PixelType = unsigned char;

    using ImageType = itk::Image<PixelType, ImageDimension>;
    using RegionType = ImageType::RegionType;
    using IndexType = ImageType::IndexType;

    using FunctionType = itk::BinaryThresholdImageFunction<ImageType>;
    using FloodFilledIteratorType = itk::FloodFilledImageFunctionConditionalConstIterator<ImageType, FunctionType>;
    using ShapedFloodFilledIteratorType =
      itk::ShapedFloodFilledImageFunctionConditionalConstIterator<ImageType, FunctionType>;

    std::vector<IndexType> seedList;

    RegionType region;
    region.SetSize(0, 128);
    region.SetSize(1, 128);
    region.SetSize(2, 128);
    region.SetIndex(0, 0);
    region.SetIndex(1, 0);
    region.SetIndex(2, 0);

    ImageType::Pointer inputImage = ImageType::New();
    inputImage->SetRegions(region);
    inputImage->Allocate(true); // initialize
                                // buffer to zero

    itk::ImageLinearIteratorWithIndex<ImageType> it(inputImage, region);

    // make sure that we create a 4-connected image!
    for (unsigned int dir = 0; dir < ImageDimension; ++dir)
    {
      it.SetDirection(dir);
      it.GoToBegin();
      while (!it.IsAtEnd())
      {
        while (!it.IsAtEndOfLine())
        {
          // add a seed
          if (seedList.empty())
          {
            seedList.push_back(it.GetIndex());
          }

          it.Set(255);
          ++it;
        }

        // and jump over every
        it.NextLine();
        if (!it.IsAtEnd())
        {
          it.NextLine();
        }
        if (!it.IsAtEnd())
        {
          it.NextLine();
        }
      }
    }

    FunctionType::Pointer function = FunctionType::New();

    function->SetInputImage(inputImage);
    function->ThresholdAbove(1); // >= 1

    FloodFilledIteratorType       floodIt(inputImage, function, seedList);
    ShapedFloodFilledIteratorType shapedFloodIt(inputImage, function, seedList);

    shapedFloodIt.SetFullyConnected(false); // 4-connected, default

    for (unsigned short i = 1; !floodIt.IsAtEnd(); ++floodIt, ++shapedFloodIt, ++i)
    {
      if (floodIt.GetIndex() != shapedFloodIt.GetIndex())
      {
        return EXIT_FAILURE;
      }
    }

    if (!floodIt.IsAtEnd() || !shapedFloodIt.IsAtEnd())
    {
      return EXIT_FAILURE;
    }
  }
  catch (const itk::ExceptionObject & e)
  {
    e.Print(std::cerr);
    return EXIT_FAILURE;
  }
  catch (...)
  {
    return EXIT_FAILURE;
  }

  return EXIT_SUCCESS;
}
